/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo;

/**
 * Safe ApplicationInfo implementation which cannot fail on initialization and return default values.
 *
 * Class designed to be used at the end of the chain in ChainedApplicationInfo.
 *
 * @see net.sf.appinfo.ChainedApplicationInfo
 *
 * @since 0.4.0
 *
 * @author Marcin Zajączkowski, 2010-10-09
 */
public class FallbackApplicationInfo extends AbstractInitAwareApplicationInfo {

    @Override
    protected void initClass() {
        setName(DEFAULT_NAME);
        setVersion(DEFAULT_VERSION);
        setBuildNumber(DEFAULT_BUILD_NUMBER);
        setBuildDate(DEFAULT_BUILD_DATE);
        setScmRevision(DEFAULT_SCM_REVISION);
    }
}
