/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo;

import net.sf.appinfo.exception.InitializationException;

/**
 * Extended interface for initialization aware classes returning partial information about application.
 *
 * @since 0.4.0
 *
 * @author Marcin Zajączkowski, 2010-10-03
 */
public interface InitAwareApplicationInfo extends ApplicationInfo {

    public static final String DEFAULT_NOT_INITED = "not inited";

    /**
     * Returns information if class is already initialized.
     *
     * @return true - class is inited
     *         false - class is not inited
     */
    public boolean isInited();

    /**
     * Starts initialization process of ApplicationInfo instance.
     *
     * TODO: MZA: Find better name (cannot be init to prevent accidental init in Spring)
     *
     * @throws net.sf.appinfo.exception.InitializationException problem with initialization
     */
    public void initInfo() throws InitializationException;
}
