/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.reader;

import net.sf.appinfo.util.AssertUtil;

import java.io.IOException;
import java.util.jar.Manifest;

/**
 * Klasa odczytująca dane z pliku manifestu znajdującego się we wskazanej lokalizacji.
 *
 * @author Marcin Zajączkowski, 2010-07-01
 */
public class FileManifestReader implements ManifestReader {

    private final String pathToManifest;
    private Manifest manifest;

    public FileManifestReader(String pathToManifest) {
        AssertUtil.notNull(pathToManifest, "pathToManifest");
        this.pathToManifest = pathToManifest;
    }

    /** {@inheritDoc} */
    public synchronized Manifest getManifest() throws IOException {
        if (manifest == null) {
            manifest = readManifestFromFile();
        }
        return manifest;
    }

    private Manifest readManifestFromFile() throws IOException {
        return new Manifest(getClass().getResourceAsStream(pathToManifest));
    }
}
