/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.util;

/**
 * Utility class with validation checks.
 *
 * Custom class with basic validation for input data created to remove library dependency on Spring.
 *
 * @since 0.5.1
 *
 * @author Marcin Zajączkowski, 2010-11-11
 */
public final class AssertUtil {

    private AssertUtil() {
        //util class
    }

    /**
     * Checks if passed object is not null (and throws IllegalArgumentException in other cvase).
     *
     * Thrown exception contains proper message with passed object name for easier identification.
     *
     * @param objectToCheck object to be checked
     * @param objectName name of passed object
     *
     * @throws IllegalArgumentException if passed object is null
     */
    public static void notNull(Object objectToCheck, String objectName) {
        if (objectToCheck == null) {
            throw new IllegalArgumentException(objectName + " cannon be null.");
        }
    }
}
