/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.util;

/**
 * Utility class with operation on String objects.
 *
 * Custom class with operation on String objects created to remove library dependency on Spring.
 *
 * @since 0.5.1
 *
 * @author Marcin Zajączkowski, 2010-11-11
 */
public final class StringUtil {

    private StringUtil() {
        //util class
    }

    /**
     * Returns true for string object which contains text.
     *
     * String has text if is not equal null and have length > 0 after trimmed.
     * 
     * @param string string object to evaluate
     * @return true if string object contains text
     *         false otherwise
     */
    public static boolean hasText(String string) {
        if (string != null) {
            //according to PMD this is more effective than string.trim().length() > 0
            // - no new String instance is being created
            for (int i=0; i<string.length(); i++) {
                if (!Character.isWhitespace(string.charAt(i))) {
                    return true;
                }
            }
        }
        return false;
    }
}
